"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var common_1 = require("./common");
var RootRef = (function () {
    function RootRef(rootDOM, componentFactoryResolver, appRef, injector) {
        this.rootDOM = rootDOM;
        this.componentFactoryResolver = componentFactoryResolver;
        this.appRef = appRef;
        this.injector = injector;
        this.isDisposed = false;
    }
    RootRef.prototype.attach = function (containerComponent, containerConfig) {
        var _this = this;
        var componentFactory = this.componentFactoryResolver.resolveComponentFactory(containerComponent);
        var componentRef;
        var injectionTokens = new WeakMap();
        injectionTokens.set(common_1.CONTAINER_DATA, containerConfig || {});
        componentRef = componentFactory.create(new common_1.PortalInjector(this.injector, injectionTokens));
        this.appRef.attachView(componentRef.hostView);
        this.setDisposeFn(function () {
            _this.appRef.detachView(componentRef.hostView);
            componentRef.destroy();
        });
        this.rootDOM.appendChild(this.getComponentRootNode(componentRef));
        return componentRef;
    };
    RootRef.prototype.dispose = function () {
        if (this.disposeFn) {
            this.disposeFn();
            this.disposeFn = null;
        }
        this.isDisposed = true;
    };
    RootRef.prototype.setDisposeFn = function (fn) {
        this.disposeFn = fn;
    };
    RootRef.prototype.getComponentRootNode = function (componentRef) {
        return componentRef.hostView.rootNodes[0];
    };
    return RootRef;
}());
exports.RootRef = RootRef;
//# sourceMappingURL=root.ref.js.map